
# Client Report

Finance_Report — Python-пакет для подсчета клиентов из городов.

## Установка

Установите библиотеку с помощью команды:

```bash
pip install client-report12
```

## Пример использования 

```bash
 client-report --input-file customers.csv --output-file repory.txt

```

## Пример исходных данных

```bash
customer_id,age,city
1,22,Москва
2,30,Санкт-Петербург
3,45,Москва
4,60,Казань
5,50,Новосибирск
6,19,Москва
7,35,Екатеринбург
8,43,Самара
9,27,Краснодар
10,21,Воронеж
11,34,Уфа
12,48,Челябинск
13,23,Нижний Новгород
14,39,Ростов-на-Дону
15,58,Пермь
16,29,Калининград
17,61,Омск
18,18,Тюмень
19,33,Владивосток
20,46,Волгоград
```